@@ -47,10 +47,10 @@ class OnSiteServices:
             self,
             order_number: int,
     ) -> dict[str, Any]:
-        order_sql = open("sql/order.sql").read().format(order_number=order_number)
-        line_sql = open("sql/linesoe.sql").read().format(order_number=order_number)
-        address_sql = open("sql/address.sql").read().format(order_number=order_number)
-        package_sql = open("sql/packimport.sql").read().format(order_number=order_number)
+        order_sql = _get_sql("order.sql", order_number=order_number)
+        line_sql = _get_sql("linesoe.sql", order_number=order_number)
+        address_sql = _get_sql("address.sql", order_number=order_number)
+        package_sql = _get_sql("packimport.sql", order_number=order_number)
 
         order_data = self._make_query(sql=order_sql)[0]
         order_data["lines"] = self._make_query(sql=line_sql)
@@ -58,3 +58,12 @@ class OnSiteServices:
         order_data["packages"] = self._make_query(sql=package_sql)
 
         return order_data
+
+
+def _get_sql(
+        file_name: str,
+        order_number: int,
+) -> str:
+    path = str(files("darbiadev_onsite").joinpath(f"sql/{file_name}"))
+    sql = open(path).read()
+    return sql.format(order_number=order_number)
